/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource;


/**
 * JNDI-related constants.
 */
public interface JndiConstants
{
   /**
    * Name of JNDI "wsrf" context (all WSRF bindings live within this context and its subcontexts).
    */
   String CONTEXT_NAME_WSRF = "wsrf";

   /**
    * JNDI path appended to JNDI service path when looking up the service's resource home
    */
   String ATOMIC_NAME_HOME = "home";

   /**
    * JNDI path appended to JNDI service path when looking up the service's resource home
    */
   String ATOMIC_NAME_GLOBAL = "global";

   /**
    * JNDI path appended to JNDI service path when looking up the service's resource home
    */
   String ATOMIC_NAME_SERVICES = "services";

   /**
    * JNDI services base path
    */
   String CONTEXT_NAME_SERVICES = CONTEXT_NAME_WSRF + "/" + ATOMIC_NAME_SERVICES;

   /**
    * Name of JNDI "resource" context.
    */
   String CONTEXT_NAME_RESOURCE = CONTEXT_NAME_WSRF + "/resource";

   /**
    * Name of JNDI "global" context.
    */
   String CONTEXT_NAME_GLOBAL = CONTEXT_NAME_WSRF + "/" + ATOMIC_NAME_GLOBAL;

   /**
    * JNDI path to the default work manager
    */
   String CONTEXT_NAME_DEFAULT_WORK_MANAGER = CONTEXT_NAME_GLOBAL + "/wm/ContainerWorkManager";

   /**
    * JNDI path to the default timer manager
    */
   String CONTEXT_NAME_DEFAULT_TIMER = CONTEXT_NAME_GLOBAL + "/timer/ContainerTimer";

   /**
    * JNDI path to the default query engine
    */
   String CONTEXT_NAME_DEFAULT_QUERY_ENGINE = CONTEXT_NAME_GLOBAL + "/query/ContainerQueryEngine";

   /**
    * JNDI path to the default topic expression engine
    */
   String CONTEXT_NAME_DEFAULT_TOPIC_EXPRESSION_ENGINE =
      CONTEXT_NAME_GLOBAL + "/topic/ContainerTopicExpressionEngine";

   /**
    * JNDI path to the default topic expression evaluator
    */
   String TOPIC_EXPRESSION_EVALUATOR_CONTEXT = CONTEXT_NAME_GLOBAL + "/topic/eval";

   /**
    * JNDI path appended to JNDI service path when looking up the service's resource metadata
    */
   String ATOMIC_METADATA_CONTEXT = "metadata";
}