/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.handler.websphere;

import org.apache.ws.resource.Resource;
import org.apache.ws.resource.ResourceException;
import org.apache.ws.resource.WsrfRuntime;
import org.apache.ws.resource.impl.ResourceContextImpl;
import org.apache.ws.util.platform.JaxRpcPlatform;
import javax.xml.soap.SOAPMessage;
import java.net.URI;
import java.net.URL;

/**
 * An implementation of ResourceContext for use when the endpoint is interacted with as an EJB.
 *
 * @author Sal Campana
 */
public class WASEjbResourceContext
   extends ResourceContextImpl
{
   private static final String UNSUPPORTED_INVOCATION =
      "This method is unsupported when invoked in the EJB context.";
   private Object              m_resourceID;

   /**
    * Creates a new {@link WASEjbResourceContext} object.
    *
    * @param serviceName DOCUMENT_ME
    * @param resourceID DOCUMENT_ME
    *
    * @throws Exception DOCUMENT_ME
    */
   public WASEjbResourceContext( String serviceName,
                                 Object resourceID )
   throws Exception
   {
      m_resourceID = resourceID;
      setServiceName( serviceName );
      setServiceURL( new URL( JaxRpcPlatform.getJaxRpcPlatform(  ).getEndpointUrl( WsrfRuntime.getRuntime(  )
                                                                                              .getBaseWebappUrl(  )
                                                                                              .toString(  ),
                                                                                   serviceName ) ) );
      lookupHome(  );
   }

   /**
    * @see ResourceContext#getRequestAction()
    */
   public String getRequestAction(  )
   {
      throw new UnsupportedOperationException( UNSUPPORTED_INVOCATION );
   }

   /**
    * @see ResourceContext#getResource()
    */
   public Resource getResource(  )
   throws ResourceException
   {
      return getResourceHome(  ).find( m_resourceID );
   }

   /**
    * @see ResourceContext#setResponseAction(URI)
    */
   public void setResponseAction( URI action )
   {
      throw new UnsupportedOperationException( UNSUPPORTED_INVOCATION );
   }

   /**
    * @see ResourceContext#getSOAPMessage()
    */
   public SOAPMessage getSOAPMessage(  )
   {
      throw new UnsupportedOperationException( UNSUPPORTED_INVOCATION );
   }
}