/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.util;

import javax.wsdl.Import;
import javax.wsdl.Input;
import javax.wsdl.Message;
import javax.wsdl.Operation;
import javax.wsdl.Output;
import javax.wsdl.Port;
import javax.wsdl.PortType;
import javax.wsdl.Service;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

/**
 * Generic utility methods for working with various JWSDL objects.
 *
 * @author Ian Springer (Hewlett-Packard Company)
 */
public abstract class WsdlUtils
{
   /**
    * DOCUMENT_ME
    *
    * @param service DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public static Map getPortTypes( Service service )
   {
      Map      portTypes = new HashMap(  );
      Map      ports     = service.getPorts(  );
      Iterator portsIter = ports.values(  ).iterator(  );
      while ( portsIter.hasNext(  ) )
      {
         Port     port     = (Port) portsIter.next(  );
         PortType portType = port.getBinding(  ).getPortType(  );
         portTypes.put( portType.getQName(  ),
                        portType );
      }

      return portTypes;
   }

   /**
    * DOCUMENT_ME
    *
    * @param import1 DOCUMENT_ME
    * @param import2 DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public static boolean equals( Import import1,
                                 Import import2 )
   {
      if ( import1 == null )
      {
         return import2 == null;
      }
      else if ( import2 == null )
      {
         return false;
      }

      return import1.getNamespaceURI(  ).equals( import2.getNamespaceURI(  ) )
             && import1.getLocationURI(  ).equals( import2.getLocationURI(  ) );
   }

   /**
    * DOCUMENT_ME
    *
    * @param op1 DOCUMENT_ME
    * @param op2 DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public static boolean equals( Operation op1,
                                 Operation op2 )
   {
      if ( op1 == null )
      {
         return op2 == null;
      }

      if ( op2 == null )
      {
         return false;
      }

      return equals( op1.getInput(  ),
                     op2.getInput(  ) ) && equals( op1.getOutput(  ),
                                                   op2.getOutput(  ) );
   }

   /**
    * DOCUMENT_ME
    *
    * @param input1 DOCUMENT_ME
    * @param input2 DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public static boolean equals( Input input1,
                                 Input input2 )
   {
      return equals( input1.getMessage(  ),
                     input2.getMessage(  ) );
   }

   /**
    * DOCUMENT_ME
    *
    * @param output1 DOCUMENT_ME
    * @param output2 DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public static boolean equals( Output output1,
                                 Output output2 )
   {
      if ( ( output1 == null ) && ( output2 == null ) )
      {
         return true;
      }

      return equals( output1.getMessage(  ),
                     output2.getMessage(  ) );
   }

   /**
    * DOCUMENT_ME
    *
    * @param msg1 DOCUMENT_ME
    * @param msg2 DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public static boolean equals( Message msg1,
                                 Message msg2 )
   {
      return msg1.getQName(  ).equals( msg2.getQName(  ) );
   }
}