/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.util.j2ee;

import com.sun.java.xml.ns.j2Ee.WebserviceDescriptionType;
import com.sun.java.xml.ns.j2Ee.WebservicesDocument;
import com.sun.java.xml.ns.j2Ee.WebservicesType;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.DirectoryScanner;
import org.apache.tools.ant.Task;
import org.apache.tools.ant.types.FileSet;
import org.apache.xmlbeans.XmlOptions;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * An Ant task that merges one or more source J2EE webservices.xml's into a target webservices.xml.
 */
public class WebservicesDDMergeTask
   extends Task
{
   private List m_sourceFiles = new ArrayList(  );
   private File m_targetFile;

   /**
    * Creates a new {@link WebservicesDDMergeTask} object.
    */
   public WebservicesDDMergeTask(  )
   {
      initContextClassLoader(  );
   }

   /**
    * Adds the specified file to the list of source web.xml's.
    *
    * @param srcFile
    */
   public void setSourceFile( File srcFile )
   {
      m_sourceFiles.add( srcFile );
   }

   /**
    * Sets the target web.xml (i.e. the web.xml to be merged into).
    *
    * @param targetFile
    */
   public void setTargetFile( File targetFile )
   {
      m_targetFile = targetFile;
   }

   /**
    * Adds the files in the specified fileset to the list of source web.xml's.
    *
    * @param fileSet DOCUMENT_ME
    */
   public void addConfiguredSourceFiles( FileSet fileSet )
   {
      File             baseDir       = fileSet.getDir( getProject(  ) );
      DirectoryScanner dirScanner    = fileSet.getDirectoryScanner( getProject(  ) );
      String[]         includedFiles = dirScanner.getIncludedFiles(  );
      for ( int i = 0; i < includedFiles.length; i++ )
      {
         m_sourceFiles.add( new File( baseDir, includedFiles[i] ) );
      }
   }

   /**
    * DOCUMENT_ME
    *
    * @throws org.apache.tools.ant.BuildException
    *          DOCUMENT_ME
    */
   public void execute(  )
   throws BuildException
   {
      if ( m_sourceFiles.isEmpty(  ) )
      {
         throw new BuildException( "No source webservices.xml files were specified!" );
      }

      try
      {
         System.out.println( "Loading target webservices document from " + m_targetFile + " ..." );
         WebservicesDocument targetDdDoc = parseWebservicesXmlFile( m_targetFile );
         WebservicesType     targetDd = targetDdDoc.getWebservices(  );
         for ( int i = 0; i < m_sourceFiles.size(  ); i++ )
         {
            mergeWebservicesDD( (File) m_sourceFiles.get( i ), targetDd );
         }

         saveTargetDocToFile( targetDdDoc );
      }
      catch ( Exception e )
      {
         throw new BuildException( e );
      }
   }

   private WebserviceDescriptionType getWebserviceDescription( WebserviceDescriptionType[] wsDescArray,
                                                               String                      wsDescName )
   {
      WebserviceDescriptionType wsDesc = null;
      for ( int i = 0; i < wsDescArray.length; i++ )
      {
         if ( wsDescArray[i].getWebserviceDescriptionName(  ).getStringValue(  ).equals( wsDescName ) )
         {
            wsDesc = wsDescArray[i];
            break;
         }
      }

      return wsDesc;
   }

   private void initContextClassLoader(  )
   {
      if ( Thread.currentThread(  ).getContextClassLoader(  ) == null )
      {
         Thread.currentThread(  ).setContextClassLoader( Task.class.getClassLoader(  ) );
      }
   }

   private void mergeWebserviceDescriptionElements( WebservicesType webservices,
                                                    WebservicesType targetWebservices )
   {
      WebserviceDescriptionType[] wsDescArray       = webservices.getWebserviceDescriptionArray(  );
      WebserviceDescriptionType[] targetWsDescArray = targetWebservices.getWebserviceDescriptionArray(  );
      for ( int i = 0; i < wsDescArray.length; i++ )
      {
         WebserviceDescriptionType wsDesc       = wsDescArray[i];
         String                    wsDescName   = wsDesc.getWebserviceDescriptionName(  ).getStringValue(  );
         WebserviceDescriptionType targetWsDesc = getWebserviceDescription( targetWsDescArray, wsDescName );
         if ( targetWsDesc == null )
         {
            targetWsDesc = targetWebservices.addNewWebserviceDescription(  );
         }

         targetWsDesc.set( wsDesc );
      }
   }

   private void mergeWebservicesDD( File            srcFile,
                                    WebservicesType targetWebservices )
   throws Exception
   {
      System.out.println( "Merging " + srcFile + " into target webservices document ..." );
      WebservicesDocument ddDoc = parseWebservicesXmlFile( srcFile );
      WebservicesType     dd = ddDoc.getWebservices(  );
      mergeWebserviceDescriptionElements( dd, targetWebservices );
   }

   private WebservicesDocument parseWebservicesXmlFile( File ddFile )
   throws Exception
   {
      XmlOptions loadOptions = new XmlOptions(  ).setLoadStripWhitespace(  );
      return WebservicesDocument.Factory.parse( ddFile, loadOptions );
   }

   private void saveTargetDocToFile( WebservicesDocument doc )
   throws IOException
   {
      System.out.println( "Saving updated target webservices document to " + m_targetFile + " ..." );
      XmlOptions saveOptions = new XmlOptions(  ).setSavePrettyPrint(  );
      doc.save( m_targetFile, saveOptions );
   }
}